@@ -39,7 +39,7 @@ use version 0.77;
 use warnings;
 
 # ABSTRACT: Test your Dist::Zilla plugin in I<build> action
-our $VERSION = 'v0.4.2_02'; # TRIAL VERSION
+our $VERSION = 'v0.4.2_03'; # TRIAL VERSION
 
 use Test::Routine;
 
@@ -168,7 +168,7 @@ test Release => sub {
 #pod         expected => {
 #pod             messages => [
 #pod                 'Created directory releases',
-#pod                 re( 'Moved to releases[/\\]Dummy-0\.003\.tar\.gz' ),
+#pod                 re( qr{Moved to releases[/\\]Dummy-0\.003\.tar\.gz} ),
 #pod             ],
 #pod             archive => 'releases/Dummy-0.003.tar.gz',
 #pod         },
@@ -181,7 +181,7 @@ test Release => sub {
 #pod         expected => {
 #pod             messages => [
 #pod                 'Created directory .archive',
-#pod                 re( 'Moved to \.archive[/\\]Dummy-0\.003\.tar\.gz' ),
+#pod                 re( qr{Moved to \.archive[/\\]Dummy-0\.003\.tar\.gz} ),
 #pod             ],
 #pod             archive => '.archive/Dummy-0.003.tar.gz',
 #pod         },
@@ -225,7 +225,7 @@ Test::Dist::Zilla::Release - Test your Dist::Zilla plugin in I<build> action
 
 =head1 VERSION
 
-Version v0.4.2_02, released on 2016-11-21 20:04 UTC.
+Version v0.4.2_03, released on 2016-11-23 21:46 UTC.
 This is a B<trial release>.
 
 =head1 SYNOPSIS
@@ -293,7 +293,7 @@ This is a B<trial release>.
         expected => {
             messages => [
                 'Created directory releases',
-                re( 'Moved to releases[/\\]Dummy-0\.003\.tar\.gz' ),
+                re( qr{Moved to releases[/\\]Dummy-0\.003\.tar\.gz} ),
             ],
             archive => 'releases/Dummy-0.003.tar.gz',
         },
@@ -306,7 +306,7 @@ This is a B<trial release>.
         expected => {
             messages => [
                 'Created directory .archive',
-                re( 'Moved to \.archive[/\\]Dummy-0\.003\.tar\.gz' ),
+                re( qr{Moved to \.archive[/\\]Dummy-0\.003\.tar\.gz} ),
             ],
             archive => '.archive/Dummy-0.003.tar.gz',
         },
